import logging
import os
# from pydriller import RepositoryMining
from datetime import datetime
from pathlib import Path
from typing import List

from .markdown import create_link, encodedpath

logger = logging.getLogger(__name__)

DIFF_TEMPLATE = "{}/commit/{}?diff=split"


def get_github_url() -> str:
    return r"https://github.com"


def get_github_userprofile_url(username) -> str:
    return get_github_url() + "/" + username


def get_github_repo_url(username) -> str:
    return get_github_userprofile_url(username) + "/" + os.path.basename(os.getcwd())


def get_raw_master_url(username) -> str:
    return get_github_repo_url(username) + "/raw/master"


def get_github_raw_link(username, filepath: str) -> str:
    filepath = os.path.relpath(filepath, start=os.getcwd())
    filepath = encodedpath(filepath)
    return get_raw_master_url(username) + "/" + filepath


def split_repo_url(repo_url) -> tuple:
    return repo_url.split("/")[-2:]


def create_rawurl(username, reponame) -> str:
    return f"https://raw.githubusercontent.com/{username}/{reponame}/master"


def generate_raw_url_from_repo_url(repo_url) -> str:
    username, reponame = split_repo_url(repo_url)
    return create_rawurl(username, reponame)


def push_to_github(gpath: Path, paths: List[Path], commit: str):
    if len(paths) > 0:
        cur_dir = os.getcwd()
        os.chdir(gpath)

        logger.info("""
        ----------------------------------------
        f"{gpath} için push işlemi:"
        ----------------------------------------
        """.strip())

        command = " &&".join([f"git add {path.relative_to(gpath)}" for path in paths])
        command += " &&" + f'git commit -m "{commit}"'
        command += " &&" + f"git push -u origin master"

        os.system(command)
        os.chdir(cur_dir)


def get_remote_url(path) -> str:
    from subprocess import Popen, PIPE

    cur_dir = os.getcwd()
    os.chdir(path)

    remote_url = ""
    try:
        with Popen(r'git config --get remote.origin.url', stdout=PIPE, stderr=PIPE) as p:
            output, errors = p.communicate()
            remote_url = output.decode('utf-8').splitlines()[0].replace(".git", "")
    except Exception as e:
        logger.error("Repo URL'i tanımlanamadı" + e)
        exit(-1)

    os.chdir(cur_dir)

    return remote_url


def list_commit_links(
    path: Path, repo_url=None, ignore_commits=[],
    since: datetime = None, to: datetime = None, table_form=False
) -> List[str]:
    from pydriller import RepositoryMining

    if not repo_url:
        repo_url = get_remote_url(path)

    links = []

    if table_form:
        links.append("|📅 Tarih|🔀 Commit|🐥 Sahibi|")
        links.append("|-|-|-|")

    for commit in RepositoryMining(str(path), reversed_order=True).traverse_commits():
        title = commit.msg.split("\n")[0]
        author = commit.author.name

        ignore = False
        for ignore_commit in ignore_commits:
            if ignore_commit in title:
                ignore = True
                continue

        if not ignore:
            hash_value = commit.hash
            time = commit.author_date.strftime("%d/%m/%Y - %H:%M:%S")
            url = DIFF_TEMPLATE.format(repo_url, hash_value)

            link = create_link(url, header=title).replace("- ", "").replace("\n", "")

            if table_form:
                link = f"|{str(time)}|{link}|{author}|"
            else:
                link = f"- {str(time)} - {link} ~ {author}"

            links.append(link)

    return links



import configparser
import logging
import shlex
import sys
from argparse import ArgumentParser
from glob import glob
from pathlib import Path
from typing import Dict

from ..lib import common, filesystem, gitbook, github, markdown

logger = logging.getLogger(__name__)

INTEGRATION_FILE = ".ygitbookintegration"
INTEGRATION_MODULE = "integration"
SUBMODULE_MODULE = "submodule"
COMMIT_UPDATE_SUBMODULES = "✨ Alt sayfalar güncellendi"

# CLI arguments
PATHSTR_LIST, DEBUG = None
GENERATE, RECREATE = None
UPDATE, CHANGELOG, REPO_URL = None
IGNORE_COMMITS, COMMIT_MSG, PUSH = None
IGNORE_COMMITS, COMMIT_MSG, PUSH = None
LEVEL_LIMIT, PRIVATES = None
INDEX_STR, NEW_INDEX_STR = None
FOOTER_PATH = None

# def execute_integrate(path: str, option: str):
#     COMMANDS = f"""
#     echo "---
#     description: Sitede neler olup bittiğinin raporudur.
#     ---" > {os.path.join(path, "CHANGELOG.md")}
#     ygitchangelog -d >> {os.path.join(path, "CHANGELOG.md")}
#     bash github {path}
#     """
#
#     # subprocess.run(f"bash -c '{COMMANDS}'")


def convert_url_form(filestr: str, url: str):
    return filestr.replace("./", url + "/").replace("README.md", "").replace(".md", "")


def read_config(cpath: Path) -> dict:
    try:
        config = configparser.ConfigParser(inline_comment_prefixes="#")
        config.read(cpath, encoding="utf-8")
    except Exception as e:
        logger.error(f"Hata oluştu {e}")
        return None

    return config


def updateSubSummaries(config: Dict, workdir: Path, index: str, push=False) -> None:
    """Alt modülleri günceller

    Arguments:
            config {dict} -- Yapılandırma dosyası verileri
            startpath {str} -- Yapılandırma dosyasının dizini

    Keyword Arguments:
            index {str} -- Limit (default: {"Index"})
            push {bool} -- Otomatik olarak git push işlemi yapma (default: {False})
    """

    def add_description(content: str, description: str) -> str:
        if description:
            return gitbook.make_description(description) + content
        else:
            return content

    def fixTitle(content: str) -> str:
        title = f"# {markdown.read_first_link(content)[1]}"
        title_changed = False

        lines = content.split("\n")

        for i in range(len(lines)):
            count = lines[i].count("#")
            if count == 1:
                lines[i] = title
                title_changed = True
                break
            elif count >= 1:
                lines[0] = title
                title_changed = True
                break

        if not title_changed:
            lines[0] = title
            title_changed = True

        return "\n".join(lines)

    def fixUrls(content, root):
        fixedlines = []
        lines = content.split("\n")
        for line in lines:
            link = markdown.find_link(line)
            if link:
                path: str = link[2]
                if not markdown.is_url(path):
                    fixedpath = path.replace(".md", "").replace("README", "")
                    fixedpath = root + "/" + fixedpath
                    line = line.replace(path, fixedpath)

            fixedlines.append(line)

        return "\n".join(fixedlines)

    paths = []
    for name in config.sections():
        if name.split()[0] == SUBMODULE_MODULE:
            section = config[name]

            path = workdir / section['path']
            url = section['url']
            root = section['root']

            description = None
            if "description" in section:
                description = section['description']

            until = None
            if "until" in section:
                until = section['until']

            content = gitbook.read_summary_from_url(url)

            substrings = markdown.generate_substrings(content, index)
            if substrings:
                content = substrings[0]

            content = fixTitle(content)
            content = fixUrls(content, root)
            content = add_description(content, description)

            if until:
                until = "## " + until
                content = content[:content.find(until)]

            filesystem.write_file(path, content)

            paths.append(path)

    if push:
        github.push_to_github(workdir, paths, COMMIT_UPDATE_SUBMODULES)


def initialize_parser():
    parser = ArgumentParser(
        description='Create `README.md` and `SUMMARY.md` file for GitBook synchronization',
    )
    parser.add_argument(
        'paths',
        nargs="+",
        metavar='paths',
        help='Projelerin yolları',
    )
    parser.add_argument(
        "--update",
        "-u",
        action="store_true",
        dest="update",
        help="Alt modüllerin summary'lerini güncelleme"
    )
    parser.add_argument(
        "--recreate",
        "-r",
        action="store_true",
        dest="recreate",
        help="Summary dosyasını baştan oluşturur"
    )
    parser.add_argument(
        "--generate",
        "-g",
        action="store_true",
        dest="generate",
        help="Markdown dışı dosyalar için README'ye bağlantılar oluşturma"
    )
    parser.add_argument(
        "--changelog",
        "-c",
        action="store_true",
        dest="changelog",
        help="Değişikliklerin raporlandığı CHANGELOG.mg dosyasını verilen URL'e göre oluşturur"
    )
    parser.add_argument(
        '--level-limit',
        '-ll',
        dest="level_limit",
        default=-1,
        help='Fonksiyonların çalışacağı en yüksek derinlik (0 => ana dizinde çalışır sadece)',
        type=int,
    )
    parser.add_argument(
        "--debug",
        "-d",
        action="store_true",
        dest="debug",
        help="Bilgilendirici metinleri gösterme"
    )
    parser.add_argument(
        "--store",
        "-s",
        action="store_true",
        dest="store",
        help="Son komutu hızlı kullanım için yapılandırma dosyasında saklar"
    )
    parser.add_argument(
        "--push",
        "-p",
        action="store_true",
        dest="push",
        help="İşlem sonrası GitHub'a otomatik pushlar"
    )
    parser.add_argument(
        "--repo-url",
        "-ru",
        dest="repo_url",
        help="Projenin git repo urli",
        type=str
    )
    parser.add_argument(
        "--commit-msg",
        "-cm",
        dest="commit_msg",
        help="Otomatik pushlama içim commit başlığı (emoji desteklemez)",
        type=str
    )
    parser.add_argument(
        "--ignore-commits",
        "-ic",
        nargs="+",
        metavar='ignore_commits',
        default=[],
        help="Değişiklik raporuna dahil edilmeyecek commit başlıkları (emoji desteklemez)"
    )
    # WARN: Kullanışsız parametreler
    parser.add_argument(
        '--index',
        '-ix',
        dest="indexStr",
        default="YPackage.YGitbookIntegration-tarafından-otomatik-oluşturulmuştur",
        help='Generated string will be inserted between given indexes',
        type=str,
    )
    # BUG: Bu yapı çalışmaz, nargs olması lazım
    parser.add_argument(
        '--privates',
        "-pp",
        dest="privates",
        default=["res", "__pycache__"],
        help='List of folder names that you dont want to add',
        type=list
    )
    parser.add_argument(
        "--footer-path",
        '-fp',
        dest="footerPath",
        help="Append the given file to end of the output. "
    )
    parser.add_argument(
        '--new-index',
        '-nix',
        dest="newIndex",
        default=None,
        help="Oluşturulan metin verilen yeni indekslerin arasına yazılır",
        type=str,
    )

    return parser


def register_args(parser: ArgumentParser, register_all=False):
    args = parser.parse_args()

    if register_all:
        global PATHSTR_LIST, DEBUG
        PATHSTR_LIST, DEBUG = args.paths, args.debug

    global GENERATE, RECREATE
    GENERATE, RECREATE = args.generate, args.recreate

    global UPDATE, CHANGELOG, REPO_URL
    UPDATE, CHANGELOG, REPO_URL = args.update, args.changelog, args.repo_url

    global IGNORE_COMMITS, COMMIT_MSG, PUSH
    IGNORE_COMMITS, COMMIT_MSG, PUSH = args.ignore_commits, args.commit_msg, args.push

    global LEVEL_LIMIT, PRIVATES
    LEVEL_LIMIT, PRIVATES = args.level_limit, args.privates

    global INDEX_STR, NEW_INDEX_STR
    INDEX_STR, NEW_INDEX_STR = args.indexStr, args.newIndex

    global FOOTER_PATH
    FOOTER_PATH = args.footerPath


def register_config_args(config: dict, path: Path) -> Dict:
    new_args = ""
    for section in config.sections():
        if section.split()[0] == INTEGRATION_MODULE:
            new_args = config[section]["args"]
            break

    if new_args:
        sys.argv = [__file__, str(path)] + shlex.split(new_args)
    else:
        logger.warning(f"""
        {str(path)} için entegrasyon özelliği mevcut değil
        {INTEGRATION_FILE}` dosyası içerisindeki `integration` alanında `args` özelliği yok
        """.strip())
        return

    parser = initialize_parser()
    register_args(parser)


def integrate(path: Path, override=False):
    if path.is_dir():
        config = read_config(path / INTEGRATION_FILE)

        if not override:
            register_config_args(config, path)

        logger.info(f"`{str(path)}` için gitbook entegrasyonu başlatılıyor.")

        if GENERATE:
            gitbook.generate_readmes(
                path, privates=PRIVATES, index=INDEX_STR,
                new_index=NEW_INDEX_STR, level_limit=LEVEL_LIMIT
            )

        if RECREATE:
            filestr = gitbook.generate_summary_filestr(
                path, level_limit=LEVEL_LIMIT, privates=PRIVATES,
                footer_path=FOOTER_PATH
            )

            gitbook.create_summary_file(path)
            gitbook.insert_summary_file(
                path, filestr, index=INDEX_STR, new_index=NEW_INDEX_STR
            )

        if UPDATE:
            updateSubSummaries(config, path, INDEX_STR, push=PUSH)

        # TIP: Committe iken yapmaktadır (önceden push edilmesine gerek yok)
        if CHANGELOG:
            gitbook.create_changelog(
                path, repo_url=REPO_URL, push=PUSH,
                ignore_commits=IGNORE_COMMITS, commit_msg=COMMIT_MSG
            )

        logger.info(f"`{str(path)}` için gitbook entegrasyonu tamamlandı.")

    else:
        logger.error(f"Hatalı yol: {path}")


def main():
    parser = initialize_parser()

    register_args(parser, register_all=True)

    common.initialize_logging(detailed=DEBUG)

    override_config = any([GENERATE, RECREATE, UPDATE, CHANGELOG])
    for pathstr in PATHSTR_LIST:
        paths = [Path(p) for p in glob(pathstr)]
        for path in paths:
            integrate(path, override=override_config)


if __name__ == "__main__":
    main()



import logging
from argparse import ArgumentParser

from ..lib.common import initialize_logging

PATTERN_ID = "?id="
URL_DRIVE = "https://drive.google.com"
PATTERN_OPEN = "open"
PATTERN_DOWNLOAD = "uc"
PATTERN_DRİVE = "https://drive.google.com"


def drive_to_direct(url: str) -> str:
    return make_direct_link(get_id(url))


def direct_to_drive(url: str) -> str:
    return make_drive_link(get_id(url))


def make_drive_link(file_id: str) -> str:
    return f"{URL_DRIVE}/{PATTERN_OPEN}{PATTERN_ID}{file_id}"


def make_direct_link(file_id: str) -> str:
    return f"{URL_DRIVE}/{PATTERN_DOWNLOAD}{PATTERN_ID}{file_id}"


def get_id(url: str) -> str:
    ix = url.find(PATTERN_ID) + len(PATTERN_ID)
    return url[ix:]


def initialize_parser() -> ArgumentParser:
    parser = ArgumentParser(
        description='Google Drive için direkt url oluşturucu',
    )
    parser.add_argument(
        'urls',
        nargs="+",
        metavar='urls',
        help='Url verileri',
    )
    parser.add_argument(
        "--reverse",
        "-r",
        action="store_true",
        dest="revers",
        help="Direkt urlden önizlenebilir url oluşturma (Kullanıcılar için)"
    )
    parser.add_argument(
        "--debug",
        "-d",
        action="store_true",
        dest="debug",
        help="Bilgilendirici metinleri gösterme"
    )

    return parser


def main():
    args = initialize_parser().parse_args()
    URLS, REVERSE, DEBUG = args.urls, args.revers, args.debug

    initialize_logging(detailed=DEBUG)

    function = drive_to_direct if not REVERSE else direct_to_drive
    for url in URLS:
        logging.info(function(url))


if __name__ == "__main__":
    main()



import logging
import re
from argparse import ArgumentParser
from copy import deepcopy
from pathlib import Path

from ..lib.common import initialize_logging
from ..lib.filesystem import copy_file, read_jsonc, write_json

logger = logging.getLogger(__name__)


def initialize_parser() -> ArgumentParser:
    parser = ArgumentParser(
        description="VSCode temaları için renk çevirici"
    )

    parser.add_argument(
        "paths",
        nargs="+",
        metavar="paths",
        help="settings.json dosyasının yolları"
    )

    parser.add_argument(
        "--debug",
        "-d",
        action="store_true",
        dest="debug",
        help="Bilgilendirici metinleri gösterme"
    )

    return parser


def generate_path_from_name(theme_name: str, postfix: str = "") -> str:
    return theme_name.replace(" ", "-").lower() + postfix + ".json"


def generate_theme(coretheme: dict, theme_settings: dict, outdir: Path, coretheme_info=()):
    # Copy core theme to remove referance
    new_theme = deepcopy(coretheme)

    # Replace colors with new ones
    for core_key, core_value in new_theme['colors'].items():
        for old_color, new_color in theme_settings['colors'].items():

            # Replace with new color if old color exists
            if old_color.lower() in core_value.lower():
                new_theme['colors'][core_key] = re.sub(
                    old_color,
                    new_color,
                    core_value,
                    flags=re.IGNORECASE
                )

    if not coretheme_info:
        # Refresh new theme name
        new_theme['name'] = theme_settings['name']

        # Generate path for new theme
        new_theme_filename = generate_path_from_name(theme_settings['name'])
        new_theme_path = outdir / new_theme_filename
    else:
        # Refresh new extension theme name
        new_theme['name'] = re.sub(
            coretheme_info[0],
            theme_settings['name'],
            new_theme['name']
        )

        new_theme_path = Path(
            str(coretheme_info[1]).replace(
                coretheme_info[0].lower(),
                theme_settings['name'].lower()
            ).replace(" ", "-")
        )

    # Write theme to file
    write_json(new_theme_path, new_theme)

    return new_theme, new_theme_path


def generate_extension(coretheme: dict, extension_setting: dict, outdir: Path):
    # Copy new theme to extend
    ext_theme = deepcopy(coretheme)

    # Insert or replace new options
    for option_key, option_value in extension_setting['options'].items():
        ext_theme['colors'][option_key] = option_value

    # Refresh extension name
    ext_theme['name'] = coretheme['name'] + extension_setting['postname']

    # Generate path for extension
    ext_theme_filename = generate_path_from_name(
        coretheme['name'], postfix=extension_setting['postfix']
    )
    ext_theme_path = outdir / ext_theme_filename

    # Write extension to file
    write_json(ext_theme_path, ext_theme)

    return ext_theme, ext_theme_path


def main():
    args = initialize_parser().parse_args()

    # Gettings args
    PATHS, DEBUG = args.paths, args.debug

    initialize_logging(detailed=DEBUG)

    for path in PATHS:
        path = Path(path)
        if not path.is_file():
            logger.error(f"{path} dosya yolu geçersiz")
            exit(-1)

        # Load settings
        settings = read_jsonc(path)

        if not all(
            key in ["coreTheme", "outputDir", "themes", "extensions"]
            for key in settings
        ):
            logger.error(f"{path} geçerli bir ayar dosyası değil")
            exit(-1)

        # Store necesssary path setttings
        coretheme_path = path.parent / Path(settings['coreTheme'])
        outdir_path = path.parent / Path(settings['outputDir'])

        # Store necesssary convertion setttings
        themes_settings = settings['themes']
        extension_settings = settings['extensions']

        # Copy core theme to outdir
        copy_file(coretheme_path, outdir_path / coretheme_path.name)

        # Load core theme setttings
        coretheme = read_jsonc(coretheme_path)

        # Generate new themes
        for theme_settings in themes_settings:
            generate_theme(coretheme, theme_settings, outdir_path)

        # Generate extensions
        for extension_setting in extension_settings:
            ext_theme, ext_theme_path = generate_extension(
                coretheme, extension_setting, outdir_path
            )

            # Generate new themes from extensions
            for theme_settings in themes_settings:
                generate_theme(
                    ext_theme, theme_settings,
                    outdir_path, coretheme_info=(coretheme['name'], ext_theme_path)
                )

            # Delete copied theme to avoid memory leak
            del ext_theme


if __name__ == "__main__":
    main()



import json
import logging
import re
from os import listdir as oslistdir
from os import rename as osrename
from os import walk
from os.path import join as path_join
from pathlib import Path
from shutil import copyfile
from typing import AnyStr, List, Pattern, Tuple
from urllib.request import urlopen

logger = logging.getLogger(__name__)


def find_level(root: Path, startpath: Path) -> int:
    """Dizin seviyesini bulma

    Arguments:
            root {Path} -- Dizin yolu
            startpath {Path} -- Ana dizin yolu

    Returns:
            int -- Derinlik seviyesi

    Examples:
            >>> result = find_level(Path("./Documents/Configuration"), Path("."))
            >>> print(result) # 2
    """
    return len(root.relative_to(startpath).parts)


def write_file(filepath: Path, string: str):
    with filepath.open("w", encoding="utf-8") as file:
        file.write(string)

        logger.info(f"{filepath} dosyası güncellendi")


def copy_file(src: Path, dst: Path):
    copyfile(src, dst)

    logger.info(f"{src} -> {dst} dosya taşındı")


def read_file(filepath: Path) -> str:
    with filepath.open("r", encoding="utf-8") as file:
        return file.read()

        logger.info(f"{filepath} dosyası okundu")


def read_jsonc(filepath: Path) -> dict:
    return json.loads(re.sub(r"//.*", "", read_file(filepath), flags=re.MULTILINE))


def read_json(filepath: Path) -> dict:
    return json.loads(read_file(filepath))


def write_json(filepath: Path, jsonstr: str, indent=4, eof_line=True):
    write_file(filepath, json.dumps(jsonstr, indent=indent) + "\n" if eof_line else "")


def read_part_of_file(filepath: Path, index: str) -> str:
    """Doysanın verilen indeksler arasında kalan kısmını okuma

    Arguments:
            filepath {Path} -- Dosya yolu objesi
            index {str} -- İndeks

    Returns:
            str -- Okunan veri
    """
    filestr = ""
    with filepath.open("r", encoding="utf-8") as file:
        read = False
        for line in file:
            if index in line.replace(" ", ""):
                read = not read
                continue

            if read:
                filestr += line

        logger.info(f"{filepath} dosyasının {index} alanı okundu")
    return filestr


def insert_file(filepath: Path, string: str, index: str, new_index: str) -> None:
    """Dosyadaki belirlirli indekslerin arasına yazma

    Arguments:
            filepath {Path} -- Dosya yolu objesi
            string {str} -- Yazılacak metin
            index {str} -- İndeks
    """
    def get_index():
        return index if not new_index else new_index

    def generate_insertion():
        insertion = ""
        if bool(string):
            index = get_index()
            insertion += index + "\n\n"
            insertion += string + "\n"
            insertion += index + "\n"
        return insertion

    def generate_filestr():
        filestr = ""
        inserted = False
        if filepath.exists():
            with filepath.open("r+", encoding="utf-8") as file:
                save = True

                for line in file:
                    if not inserted and index in line.replace(" ", ""):
                        filestr += generate_insertion()
                        save = False
                        inserted = True
                    else:
                        if not inserted or save:
                            filestr += line
                        else:
                            if index in line.replace(" ", ""):
                                save = True

        else:
            filestr = generate_insertion()
            inserted = True

        # If no insertion happend, create new section
        if not inserted:
            # BUG: If index is not found in the file while new index used, index string is
            # BUG: dublicated
            # WARN: "\n" olmazsa satırın ucuna eklemekte, bu da indexin olduğu satırın
            # WARN: kaybolmasından dolayı verinin silinmesine neden olmakta
            new_line_count = 2 - filestr[-2:].count("\n")
            filestr += "\n" * new_line_count
            filestr += generate_insertion()
            inserted = True

        return filestr

    def write_insertion() -> None:
        filestr = generate_filestr()

        if filestr != read_file(filepath):
            write_file(filepath, filestr)

    return write_insertion()


def listdir_grouped(root: Path, privates=[], include_hidden=False) -> Tuple[List, List]:
    """Dizindeki dosya ve dizinleri sıralı olarak listeler

    Arguments:
            root {Path} -- Listenelecek dizin

    Keyword Arguments:
            privates {list} -- Atlanılacak yollar (default: {[]})
            include_hidden {bool} -- Gizli dosyaları dahil etme (default: {False})

    Returns:
            tuple -- dizin, dosya listesi

    Examples:
            >>> dirs, files = listdir_grouped(".")
    """
    paths = [x for x in root.iterdir()]

    dirs, files = [], []
    for path in paths:
        if not (not include_hidden and path.name.startswith('.')) and path.name not in privates:
            dirs.append(path) if path.is_dir() else files.append(path)

    dirs.sort()
    files.sort()

    return dirs, files


def read_file_by_url(rawUrl: str, encoding="utf-8") -> str:
    """URLdeki dosyayı okuma

    Arguments:
            rawUrl {str} -- URL (https, http)

    Keyword Arguments:
            encoding {str} -- Dosya kodlanması (default: {"utf-8"})

    Returns:
            str -- Okunan metin
    """
    return urlopen(rawUrl).read().decode(encoding)


def repeat_for_subdirectories(startpath: Path, func: callable) -> None:
    for root, dirs, files in walk(startpath):
        # Sıralama her OS için farklı olabiliyor
        dirs.sort()
        files.sort()

        root = Path(root)

        lvl = find_level(root, startpath)
        func(root, lvl, "dir")

        for f in files:
            fpath = path_join(root, f)
            func(fpath, lvl, "file")


def rename(regex: Pattern[AnyStr], to: str, path: str) -> None:
    result = regex.search(path)
    if result:
        if result.lastindex:
            for i in range(result.lastindex + 1):
                to = to.replace(f"${i}", result[i])

        dst = regex.sub(to, path)
        osrename(path, dst)

        logger.info(f"{path} -> {dst} taşındı")


def compile_regex(pattern, ignore_case=False) -> Pattern[AnyStr]:
    if ignore_case:
        p = re.compile(pattern, re.IGNORECASE)
    else:
        p = re.compile(pattern)

    return p


def rename_folders(
        startpath: str, pattern: str, to: str,
        ignore_case=True, recursive=False
):
    p = compile_regex(pattern, ignore_case=ignore_case)
    if recursive:
        for root, dirs, _ in walk(startpath):
            rename(p, to, root)
    else:
        for path in oslistdir(startpath):
            if Path(path).is_dir():
                rename(p, to, path)


def rename_files(
        startpath: str, pattern: str, to: str,
        ignore_case=True, recursive=False
):
    p = compile_regex(pattern, ignore_case=ignore_case)
    if recursive:
        for root, dirs, files in walk(startpath):
            for f in files:
                path = path_join(root, f)
                rename(p, to, path)
    else:
        for path in oslistdir(startpath):
            if Path(path).is_file():
                rename(p, to, path)



import logging
from argparse import ArgumentParser

from ..lib.common import initialize_logging
from ..lib.filesystem import rename_files, rename_folders


def initialize_parser():
    parser = ArgumentParser(
        description="Dosya veya dizinleri topluca adlandırma aracı"
    )

    parser.add_argument(
        'paths',
        nargs="+",
        metavar='paths',
        help='Dizin yolları',
    )
    parser.add_argument(
        "--recursive",
        "-r",
        action="store_true",
        dest="recursive",
        help="Dizin içerisindeki tüm içerikleri ele alır"
    )
    parser.add_argument(
        "--silent",
        "-s",
        action="store_true",
        dest="silent",
        help="İşlemleri çıktı göstermeden tamamlar"
    )
    parser.add_argument(
        "--dir",
        "-d",
        action="store_true",
        dest="dir_mode",
        help="Dosya yerine dizinlerin adlarını değiştirir"
    )
    parser.add_argument(
        "--pattern",
        "-p",
        dest="pattern",
        help="Değiştirilecek isimleri belirten regex şablonu",
        required=True
    )
    parser.add_argument(
        "--to",
        "-t",
        dest="to",
        help="Şablona uygun isimleri verilen değer ile değiştirir",
        required=True
    )
    parser.add_argument(
        "--c",
        "--case-sensitive",
        action="store_true",
        dest="case_sensitive",
        help="BÜyük küçük harf duyarlılığını aktif eder"
    )

    return parser


def main():
    args = initialize_parser().parse_args()

    PATHS = args.paths
    RECURSIVE, CASE_SENSITIVE, DIR_MODE = args.recursive, args.case_sensitive, args.dir_mode
    PATTERN, TO = args.pattern, args.to
    SILENT = args.silent

    initialize_logging()

    if SILENT:
        logging.basicConfig(level=logging.ERROR)

    for path in PATHS:
        function = rename_folders if DIR_MODE else rename_files
        function(path, PATTERN, TO, ignore_case=not CASE_SENSITIVE, recursive=RECURSIVE)


if __name__ == "__main__":
    main()



import logging
import os
from datetime import datetime
from pathlib import Path

from .filesystem import (find_level, listdir_grouped, read_file_by_url,
                         write_file)
from .github import (generate_raw_url_from_repo_url, get_github_raw_link,
                     list_commit_links, push_to_github)
from .markdown import (SpecialFile, check_links, create_header, create_link,
                       create_markdown_file, generate_dirlink,
                       generate_filelink, insert_file, make_linkstr)

logger = logging.getLogger(__name__)

DESCRIPTIPON_TEMPLATE = """---
description: >-
  {}
---

"""

SUMMARY_FILE = "SUMMARY.md"
SUMMARY_FILE_HEADER = "# Summary"

CHANGELOG_FILE = "CHANGELOG.md"
CHANGELOG_HEADER = u"👀 Neler değişti"
CONTRIBUTING_HEADER = u"💖 Katkıda Bulunma Rehberi"
GITHUB_USERNAME = "yedhrab"


def make_description(string: str) -> str:
    return DESCRIPTIPON_TEMPLATE.format(string)


def get_specialfile_header(specialfile: SpecialFile) -> str:
    if specialfile == SpecialFile.CHANGELOG_FILE:
        return CHANGELOG_HEADER
    elif specialfile == SpecialFile.CONTRIBUTING_FILE:
        return CONTRIBUTING_HEADER


def make_file_link(filepath: Path, root: Path = None, direct_link: bool = False) -> str:
    if root is None:
        root = filepath.parent

    if direct_link:
        return make_linkstr(filepath.name, get_github_raw_link(GITHUB_USERNAME, filepath))
    else:
        return create_link(filepath, root=root)


def generate_fs_link(
        lines: list, root: Path, startpath: Path = None, level_limit: int = -1, privates=[]
) -> list:
    # TODO: Buranın markdown'a aktarılması lazım
    # RES: Decalator kavramının araştırılması lazım olabilir

    def append_rootlink(lines: list, root: Path, level: int) -> str:
        dirlink = generate_dirlink(root, startpath=startpath, ilvl=level, isize=2)
        lines.append(dirlink)
        return lines

    def append_filelink(lines: list, fpath: Path, level: int):
        filelink = generate_filelink(fpath, startpath=startpath, ilvl=level, isize=2)
        lines.append(filelink)
        return lines

    def append_sublinks(lines: list, root: Path, level: int, dirs_only=False):
        dirs, files = listdir_grouped(root, privates=privates)
        for dpath in dirs:
            lines = generate_fs_link(lines, dpath, startpath=startpath, privates=privates)

        if not dirs_only:
            for fpath in files:
                if ".md" in fpath.name and SpecialFile.README_FILE.value not in fpath.name:
                    lines = append_filelink(lines, fpath, level)

        return lines

    def append_links(lines: list):
        nonlocal startpath
        if startpath is None:
            startpath = root
            level = find_level(root, startpath)
            if level_limit == -1 or level <= level_limit:
                lines = append_sublinks(lines, root, level + 1, dirs_only=True)
        else:
            level = find_level(root, startpath)
            if level_limit == -1 or level <= level_limit:
                lines = append_rootlink(lines, root, level)
                lines = append_sublinks(lines, root, level + 1)
        return lines

    return append_links(lines)


def get_summary_path(workdir: Path) -> Path:
    return workdir / SUMMARY_FILE


def create_summary_file(workdir: Path):
    filepath = get_summary_path(workdir)
    if not filepath.exists():
        write_file(filepath, SUMMARY_FILE_HEADER + "\n\n")


def generate_summary_filestr(
        workdir: Path, level_limit: int = -1, privates=[], footer_path=None
):

    def append_header(filestr):

        def append_firstline(lines: list) -> list:
            headpath = SpecialFile.README_FILE.get_filepath(root=workdir)
            header_link = generate_filelink(headpath, startpath=workdir)
            lines.append(header_link)
            return lines

        def append_specialfiles(lines: list, *specialfiles: SpecialFile) -> list:
            for specialfile in specialfiles:
                specialfile_path = specialfile.get_filepath(workdir)
                if specialfile_path:
                    specialfile_link = generate_filelink(
                        specialfile_path,
                        header=get_specialfile_header(specialfile),
                        startpath=workdir,
                        ilvl=find_level(workdir, workdir) + 1,
                        isize=2
                    )
                    lines.append(specialfile_link)

            return lines

        lines = append_firstline([])
        lines = append_specialfiles(
            lines,
            SpecialFile.CHANGELOG_FILE,
            SpecialFile.CONTRIBUTING_FILE
        )

        filestr += "".join(lines)
        return filestr

    def append_markdown_links(filestr: str):
        lines = generate_fs_link([], workdir, level_limit=level_limit, privates=privates)
        filestr += "".join(lines)
        return filestr

    def append_footer(filestr: str):
        if footer_path and os.path.isfile(footer_path):
            with open(os.path.join(footer_path), "r", encoding="utf-8") as file:
                filestr = "\n" + \
                    file.read()
        return filestr

    filestr = append_header("")
    filestr = append_markdown_links(filestr)
    filestr = append_footer(filestr)

    return filestr


def insert_summary_file(
    workdir: Path, filestr: str, index: str = "Index", new_index: str = None
):
    FILEPATH = get_summary_path(workdir)
    insert_file(FILEPATH, filestr, index=index, new_index=new_index)


def generate_summary(
        workdir, level_limit: int = -1, privates=[], footer_path=None,
        index: str = "Index", new_index: str = None
):
    filestr = generate_summary_filestr(
        workdir, level_limit=level_limit, privates=privates, footer_path=footer_path)
    insert_summary_file(workdir, filestr, index=index, new_index=new_index)


def generate_readmes(
        startpath: Path, level_limit: int = -1, privates=[], index="Index", header=None,
        new_index=None, clearify=False, direct_link: bool = False
):
    # DEV: Ders notlarını README'ye ekleme direkt olarak dizin dosya oluştur
    def clear_private_dirs() -> list:
        return [d for d in dirs if not d.startswith('.') and d not in privates]

    def generate_links_for_nonmarkdowns(files) -> str:
        # OLD: Eski yapıdır, kontrollü bir şekilde kaldırılmalı
        filestr = ""
        links = []
        for f in files:
            if ".md" not in f:
                links.append(make_file_link(startpath / f, direct_link=direct_link))

        if bool(links):
            filestr = create_header(header, 2) if header else ""
            filestr += "".join(links)

        return filestr

    def generate_markdown_files_for_subitems(startpath: Path, clearify=False) -> str:
        # DEV: Aynı dizindekiler aynı dosya altına yazılacak
        for root, dirs, files in os.walk(startpath):
            # Sıralama her OS için farklı olabiliyor
            dirs.sort()
            files.sort()

            root = Path(root)
            if root == startpath:
                continue

            level = find_level(root, startpath)
            link_root = root.parent
            for _ in range(level - 1):
                link_root = link_root.parent

            links = []
            for f in files:
                subfilepath = root / f
                if ".md" not in f:
                    links.append(make_file_link(subfilepath, root=root, direct_link=direct_link))
                elif f != SpecialFile.README_FILE.value:
                    # DEV: Markdown dosyaları README'nin altına eklensin
                    links.append(create_link(subfilepath, root=link_root))

            if bool(links):
                filestr = create_header(header, 2) if header else ""
                filestr += "".join(links)

                filepath = SpecialFile.README_FILE.get_filepath(root=Path(root))
                if not os.path.exists(filepath):
                    oldfile = os.path.join(startpath, os.path.basename(root) + ".md")
                    if clearify:
                        try:
                            os.rename(oldfile, filepath)

                            logger.info(oldfile + " -> " + filepath + " taşındı")
                        except Exception as e:
                            create_markdown_file(filepath, os.path.basename(root))
                            logger.error(f"{oldfile} aktarılamadı. {e}")

                insert_file(filepath, filestr, index=index, force=True,
                            fileheader=os.path.basename(root), new_index=new_index)

    filestr = ""
    for root, dirs, files in os.walk(startpath):
        # Remove private directories
        dirs[:] = clear_private_dirs()

        # Sıralama her OS için farklı olabiliyor
        dirs.sort()
        files.sort()

        root = Path(root)

        # Skip startpath
        if root == startpath:
            continue

        filestr = ""
        level = find_level(root, startpath)
        if level_limit == -1 or level < level_limit:
            filestr = generate_links_for_nonmarkdowns(files)
        elif level == level_limit:  # 1
            generate_markdown_files_for_subitems(root, clearify=clearify)
        else:
            if clearify and level > level_limit:
                readme_path = SpecialFile.README_FILE.get_filepath(root=root)
                if os.path.exists(readme_path):
                    os.remove(readme_path)
            continue

        if bool(filestr):
            filepath = SpecialFile.README_FILE.get_filepath(root=root)
            fileheader = os.path.basename(root)
            insert_file(filepath, filestr, index=index, force=True,
                        fileheader=fileheader, new_index=new_index)


def get_summary_url_from_repo_url(repo_url):
    return generate_raw_url_from_repo_url(repo_url) + "/" + SUMMARY_FILE


def read_summary_from_url(repo_url):
    raw_url = get_summary_url_from_repo_url(repo_url)
    return read_file_by_url(raw_url)


def check_summary(path):
    spath = os.path.join(path, SUMMARY_FILE)
    check_links(spath)


def create_changelog(
    path: Path, ignore_commits=[], repo_url=None, since: datetime = None,
    to: datetime = None, push=False, commit_msg=None
):
    if not commit_msg:
        commit_msg = "💫 YGitBookIntegration"

    cpath = path / CHANGELOG_FILE

    filestr = "# ✨ Değişiklikler"
    filestr += "\n\n"
    filestr += "## 📋 Tüm Değişiklikler"
    filestr += "\n\n"

    links = list_commit_links(
        path, repo_url=repo_url, since=since, to=to,
        ignore_commits=ignore_commits + [commit_msg]
    )
    filestr += "\n".join(links)

    oldfilestr = ""
    if cpath.exists():
        with cpath.open("r", encoding="utf-8") as file:
            oldfilestr = file.read()

    if oldfilestr != filestr:
        write_file(cpath, filestr)

        if push:
            push_to_github(path, [cpath], commit_msg)



import os
import re
from enum import Enum
from pathlib import Path
from urllib.parse import quote

from .common import generate_substrings as c_generate_substrings
from .filesystem import insert_file as fs_insert_file

LINK_REGEX = r"\[([^\[]+)\]\((.*)\)"


class SpecialFile(Enum):
    README_FILE = "README.md"
    CHANGELOG_FILE = "CHANGELOG.md"
    CODE_OF_CONTACT = "CODE_OF_CONDUCT.md"
    CONTRIBUTING_FILE = "CONTRIBUTING.md"
    LICANSE_FILE = "Licanse.md"

    def get_filepath(self, root: Path = Path.cwd()) -> Path:
        return root / self.value

# DEV: Figure out index string in markdown file


def remove_extension(filepath: str) -> str:
    """Dosya uzantısını kaldırma

    Args:
            filepath (str): Dosya yolu

    Returns:
            str: Uzantsız dosya yolu
    """

    filepath, _ = os.path.splitext(filepath)
    return filepath


def barename(path: str) -> str:
    """Dosya veya dizin yolundan, yol ve uzantıyı temizleme

    Args:
            filepath (str): Dosya yolu

    Returns:
            str: Sadece dosya ismi
    """

    pathname = path
    if os.path.isfile(path):
        pathname = remove_extension(path)

    pathname = os.path.basename(pathname)

    return pathname


def encodedpath(path: str) -> str:
    """ Verilen yolu url formatında kodlama

    Windows için gelen '\\' karakteri '/' karakterine çevrilir

    Args:
            pathname (str): Yol ismi

    Returns:
            str: Kodlanmış metin
    """

    return quote(path.replace("\\", "/"))


def create_indent(level, size=2):
    return ' ' * size * (level)


def make_linkstr(header, link):
    return f"- [{header}]({link})\n"


def is_url(link: str) -> bool:
    return "https://" in link or "http://" in link


def create_link(path: Path, header: str = None, root: Path = Path.cwd(), ilvl=0, isize=2) -> str:
    """Verilen yola uygun kodlanmış markdown linki oluşturma

    Arguments:
            path {str} -- Yol

    Keyword Arguments:
            header {str} -- Link başlığı (default: {None})
            root {str} -- Ana dizin (default: {os.getcwd()})
            ilvl {int} -- Girinti seviyesi (default: {0})
            isize {int} -- Girinti birim uzunluğu (default: {2})

    Returns:
            str -- Girintili markdown bağlatısı
    """

    if not header:
        header = path.name

    if not is_url(str(path)):
        path = path.relative_to(root)
        path = encodedpath(str(path))

    indent = create_indent(ilvl, size=isize)
    linkstr = make_linkstr(header, path)

    return '{}{}'.format(indent, linkstr)


def create_header(name: str, headerlvl: int) -> str:
    return "#" * headerlvl + f" {name}\n\n"


def read_first_header(filepath: Path):
    header = ""
    if filepath.exists():
        with filepath.open("r", encoding="utf-8") as file:
            for line in file:
                if line.startswith("#"):
                    header = line.strip().replace("# ", "")
                    break

        if "<!--" in header:
            header = header[:header.index("<!--")].strip()

    return header


def read_first_link(string: str) -> dict:
    """İlk link verisini döndürür

    Arguments:
            string {str} -- Link aranacak metin dosyası

    Returns:
            dict -- Link verisi

    Examples:
            >>> result[0] = "[name](url)"
            >>> result[1] = "name"
            >>> result[2] = "url"
    """
    return re.search(f"{LINK_REGEX}|$", string)


def remove_title(string: str) -> str:
    lines = string.split("\n")
    for line in lines:
        if line.count("#") == 1:
            lines.remove(line)
            break
        # 1'den fazla gelirse title yok demektir
        elif line.count("#") >= 1:
            break

    return "\n".join(lines)


def find_link(line: str) -> dict:
    """Varsa link verisini döndürür

    Arguments:
            string {str} -- Bağlantı aranacak metin dosyası

    Returns:
            dict -- Bulunan bağlantılar

    Examples:
            >>> result = find_link("- [name](url)")
            >>> result[0] = "[name](url)"
            >>> result[1] = "name"
            >>> result[2] = "url"
    """
    return re.search(LINK_REGEX, line)


def findall_links(string: str) -> dict:
    """Tüm linkleri döndürür

    Arguments:
            string {str} -- Bağlantı aranacak metin dosyası

    Returns:
            dict -- Bulunan bağlantılar

    Examples:
            >>> result[0] = ('name', 'url')
            >>> result[0][1] = "name"
            >>> result[0][1] = "url"
    """
    return re.findall(LINK_REGEX, string)


def generate_filelink(
    fpath: Path, startpath: str = os.getcwd(),
    header: str = None, ilvl=0, isize=2
) -> str:
    """Dosya için markdown linki oluşturur

    Arguments:
            path {str} -- Yol

    Keyword Arguments:
            header {str} -- Link başlığı (default: {None})
            root {str} -- Ana dizin (default: {os.getcwd()})
            ilvl {int} -- Girinti seviyesi (default: {0})
            isize {int} -- Girinti birim uzunluğu (default: {2})

    Returns:
            str -- Girintili markdown bağlatısı
    """
    if not header:
        header = read_first_header(fpath)

    return create_link(fpath, header=header, root=startpath, isize=isize, ilvl=ilvl)


def generate_dirlink(root: Path, startpath: str = os.getcwd(), ilvl=0, isize=2) -> str:
    """Dizin için markdown linki oluşturur
    README.md varsa ona bağlantı verir

    Arguments:
            path {Path} -- Yol

    Keyword Arguments:
            header {str} -- Link başlığı (default: {None})
            root {str} -- Ana dizin (default: {os.getcwd()})
            ilvl {int} -- Girinti seviyesi (default: {0})
            isize {int} -- Girinti birim uzunluğu (default: {2})

    Returns:
            str -- Girintili markdown bağlatısı
    """

    dirlink = ""
    readme_path = SpecialFile.README_FILE.get_filepath(root)
    if readme_path:
        header = read_first_header(readme_path)
        dirlink = create_link(
            readme_path, header=header, root=startpath, isize=isize, ilvl=ilvl
        )
    else:
        dirlink = create_link(root, root=startpath, isize=isize, ilvl=ilvl)

    return dirlink


def make_comment(string):
    return f"<!--{string}-->"


def insert_file(
    filepath: Path, string, index, force=False, fileheader=None, new_index=None
):
    if force and not filepath.exists():
        create_markdown_file(filepath, header=fileheader)

    index = make_comment(index)

    if bool(new_index):
        new_index = make_comment(new_index)

    fs_insert_file(filepath, string, index=index, new_index=new_index)


def create_markdown_file(filepath: Path, header=None):
    if not bool(header):
        header = filepath.name

    with filepath.open("w", encoding="utf-8") as file:
        file.write(create_header(header,  1))


def generate_substrings(content, index):
    index = make_comment(index)
    return c_generate_substrings(content, index)


def check_links(fpath):
    with open(fpath, "r", encoding="utf-8") as f:
        for line in f:
            found = find_link(line)
            if found:
                path = found[2]
                if not is_url(path):
                    result = os.path.exists(path)
                    if not result:
                        print(path)



from distutils.core import setup
import setuptools

README_PATH = "docs/README.md"
DYNAMIC_VERSION = False
VERSION = "2.7.0"

if DYNAMIC_VERSION:
    version = ""
    with open(".version", "r", encoding="utf-8") as file:
        version = (int(file.read().strip()) + 1) / 10
else:
    version = VERSION

long_description = ""
with open(README_PATH, "r", encoding="utf-8") as file:
    long_description = file.read()


setup(
    name='ypackage',             # How you named your package folder (MyLib)
    packages=setuptools.find_packages(),   # Chose the same as "name"
    # Start with a small number and increase it with every change you make
    version=version,
    # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    license='MIT',
    # Give a short description about your library
    description="Yunus Emre Ak ~ YEmreAk (@yedhrab)'ın google drive direkt link oluşturma" +
    "gitbook entegrasyonu, google arama motoru sonuçlarını filtreleme ile ilgili çalışmaları ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Yunus Emre Ak',
    author_email='yedhrab@gmail.com',
    url='https://github.com/yedhrab/YPackage',
    # Paketi açıklayan anahtar kelimeler
        keywords=[
        'ypackage', 'yedhrab', 'yemreak', 'gitbook', 'github',
        'google-search', "google", "link", "drive", "renamer", "bulk"
    ],
    # Kurulacak alt paketler
    install_requires=[
        "google",
        "requests",
        "pydriller"
    ],
    classifiers=[
            # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable"
        'Development Status :: 5 - Production/Stable',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    entry_points={
            # Komut isteminden çalıştırma
        # örndeğin: ypackage
        # Kullanım: 'ypacakge = ypackage.ypackage:main
        'console_scripts': [
            'ygitbookintegration = ypackage.util.integrate_into_gitbook:main',
            "ygoogledrive = ypackage.util.gdrive:main",
            "ygooglesearch = ypackage.util.gsearch:main",
            "yfilerenamer = ypackage.util.file_renamer:main",
            "ythemecreator = ypackage.util.theme_creator:main"
        ]
    }
)

if DYNAMIC_VERSION:
    with open(".version", "w", encoding="utf-8") as file:
        file.write(str(int(version * 10)))



import logging
import re
from argparse import ArgumentParser

import googlesearch
import requests

from ..lib.common import initialize_logging

logger = logging.getLogger(__name__)


def get_status_code(url) -> str:
    try:
        status_code = str(requests.head(url, allow_redirects=True).status_code)
    except Exception:
        status_code = "404+"
    return status_code


def log_url_by_status(
        query: str, fpath: str, status_code: str = None, exclude: str = None, mode="a"
) -> None:

    def write_file(string, file):
        file.write(string + "\n")
        file.flush()

    file = open(fpath, mode)

    removal = []
    if exclude:
        with open(exclude, "r") as exfile:
            removal = exfile.read().split("\n")

    urls = googlesearch.search(query, pause=5.0)
    for url in urls:
        if url not in removal:
            if not status_code:
                result = f"{url}"
                write_file(result, file)
            else:
                scode = get_status_code(url)
                if status_code in scode:
                    write_file(url, file)

    file.close()


def initialize_parser() -> ArgumentParser:
    parser = ArgumentParser(
        description='Google arama sonuçlarını raporlama',
    )
    parser.add_argument(
        'queries',
        nargs="+",
        metavar='queries',
        help='Sorgular (google üzerinde aratılan metin)',
    )
    parser.add_argument(
        '--status-code',
        "-sc",
        dest='status_code',
        help='HTTP durum kodu',
        default=None
    )
    parser.add_argument(
        '--output',
        "-o",
        dest='output',
        help='Tüm çıktılar tek bir dosyaya aktarılır',
        default=None
    )
    parser.add_argument(
        '--exclude',
        "-ex",
        dest='exclude',
        help='Verilen dosya içerisindeki urlleri raporlamaz',
        default=None
    )

    parser.add_argument(
        "--debug",
        "-d",
        action="store_true",
        dest="debug",
        help="Bilgilendirici metinleri gösterme"
    )

    return parser


def main():
    args = initialize_parser().parse_args()

    QUERIES, STATUS_CODE, EXCLUDE = args.queries, args.status_code, args.exclude
    OUTPUT, DEBUG = args.output, args.debug

    initialize_logging(detailed=DEBUG)

    for query in QUERIES:
        filename = re.sub(r"[^\w ]", "_", query) + ".txt" if not OUTPUT else OUTPUT
        condition = f"{STATUS_CODE}" if STATUS_CODE else "herhangi bir"
        excluded_file = f"{EXCLUDE} dosyasında olmayan" if EXCLUDE else "tüm"

        logger.info(f"""
        {query} sorgusu için {filename} dosyasına {condition} http durumuna sahip olan
        {excluded_file} bağlantılar raporlanıyor.
        """.strip())

        log_url_by_status(query, filename, status_code=STATUS_CODE, exclude=EXCLUDE)


if __name__ == "__main__":
    main()
